@@ -7,6 +7,7 @@ import getpass
 import io
 import os
 import pwd
+import re
 import shlex
 import sys
 import textwrap
@@ -14,6 +15,7 @@ from functools import partial
 from urllib.parse import urlparse
 
 from landscape.client import GROUP
+from landscape.client import IS_SNAP
 from landscape.client import USER
 from landscape.client.broker.amp import RemoteBrokerConnector
 from landscape.client.broker.config import BrokerConfiguration
@@ -110,6 +112,7 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
         "silent",
         "ok_no_register",
         "import_from",
+        "skip_registration",
     )
 
     encoding = "utf-8"
@@ -246,6 +249,11 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             "registered else returns {}. Displays "
             "registration info.".format(EXIT_NOT_REGISTERED),
         )
+        parser.add_option(
+            "--skip-registration",
+            action="store_true",
+            help="Don't send a new registration request",
+        )
         return parser
 
 
@@ -467,12 +475,14 @@ class LandscapeSetupScript:
             show_help(
                 "Provide the fully qualified domain name "
                 "of your Landscape Server e.g. "
-                "landscape.yourdomain.com",
+                "landscape.example.com",
             )
             self.landscape_domain = self.prompt_get_input(
                 "Landscape Domain: ",
                 True,
-            )
+            ).strip("/")
+            self.landscape_domain = re.sub(r"^https?://", "",
+                                           self.landscape_domain)
             self.config.ping_url = f"http://{self.landscape_domain}/ping"
             self.config.url = f"https://{self.landscape_domain}/message-system"
         else:
@@ -507,7 +517,10 @@ class LandscapeSetupScript:
             "https_proxy",
             "http_proxy",
         )
-        cmd = ["sudo", "landscape-config"]
+        cmd = [
+            "sudo",
+            "landscape-client.config" if IS_SNAP else "landscape-config",
+        ]
         for param in params:
             value = self.config.get(param)
             if value:
@@ -520,7 +533,7 @@ class LandscapeSetupScript:
                 else:
                     cmd.append(shlex.quote(value))
         show_help(
-            "The landscape-config parameters to repeat this registration"
+            "The landscape config parameters to repeat this registration"
             " on another machine are:",
         )
         show_help(" ".join(cmd))
@@ -942,6 +955,10 @@ def main(args, print=print):
 
     # Attempt to register the client.
     reactor = LandscapeReactor()
+
+    if config.skip_registration:
+        return
+
     if config.silent:
         result = register(
             config,
