@@ -8,7 +8,6 @@ from unittest import mock
 from twisted.internet.defer import Deferred
 from twisted.internet.defer import fail
 from twisted.internet.defer import succeed
-from twisted.python.compat import iteritems
 
 from landscape.client.broker.registration import Identity
 from landscape.client.broker.registration import RegistrationError
@@ -384,6 +383,56 @@ class LandscapeSetupScriptTest(LandscapeTest):
         )
         self.assertEqual(self.config.account_name, "standalone")
 
+    @mock.patch(
+        "landscape.client.configuration.input",
+        return_value="http://landscape.hello.com",
+    )
+    @mock.patch(
+        "landscape.client.configuration.prompt_yes_no",
+        return_value=True,
+    )
+    @mock.patch("landscape.client.configuration.show_help")
+    def test_prompt_landscape_edition_strip_http(
+        self,
+        mock_help,
+        prompt_yes_no,
+        mock_input,
+    ):
+        self.script.query_landscape_edition()
+        self.assertEqual(
+            self.config.ping_url,
+            "http://landscape.hello.com/ping",
+        )
+        self.assertEqual(
+            self.config.url,
+            "https://landscape.hello.com/message-system",
+        )
+
+    @mock.patch(
+        "landscape.client.configuration.input",
+        return_value="https://landscape.hello.com",
+    )
+    @mock.patch(
+        "landscape.client.configuration.prompt_yes_no",
+        return_value=True,
+    )
+    @mock.patch("landscape.client.configuration.show_help")
+    def test_prompt_landscape_edition_strip_https(
+        self,
+        mock_help,
+        prompt_yes_no,
+        mock_input,
+    ):
+        self.script.query_landscape_edition()
+        self.assertEqual(
+            self.config.ping_url,
+            "http://landscape.hello.com/ping",
+        )
+        self.assertEqual(
+            self.config.url,
+            "https://landscape.hello.com/message-system",
+        )
+
     @mock.patch(
         "landscape.client.configuration.input",
         return_value="landscape.hello.com",
@@ -760,7 +809,9 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
         try:
             config.config = config_file
             config.write()
-            return open(config.config).read().strip() + "\n"
+            with open(config.config) as fh:
+                text = fh.read().strip() + "\n"
+            return text
         finally:
             config.config = original_config
 
@@ -788,7 +839,7 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
                 "Will you be using your own "
                 "Self-Hosted Landscape installation? [y/N]": "n",
             }
-            for key, value in iteritems(fixtures):
+            for key, value in fixtures.items():
                 if key in prompt:
                     return value
             raise KeyError(f"Couldn't find answer for {prompt}")
@@ -798,7 +849,7 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
                 "(Optional) Registration Key:": "New Password",
                 "Please confirm:": "New Password",
             }
-            for key, value in iteritems(fixtures):
+            for key, value in fixtures.items():
                 if key in prompt:
                     return value
             raise KeyError(f"Couldn't find answer for {prompt}")
@@ -839,6 +890,65 @@ class ConfigurationFunctionsTest(LandscapeConfigurationTest):
         self.assertEqual(config.https_proxy, "https://new.proxy")
         self.assertEqual(config.include_manager_plugins, "")
 
+    @mock.patch("landscape.client.configuration.IS_SNAP", "1")
+    @mock.patch("landscape.client.configuration.print_text")
+    @mock.patch("landscape.client.configuration.getpass.getpass")
+    @mock.patch("landscape.client.configuration.input")
+    @mock.patch("landscape.client.configuration.show_help")
+    def test_setup_on_the_snap_version(
+        self,
+        mock_help,
+        mock_input,
+        mock_getpass,
+        mock_print_text,
+    ):
+        filename = self.makeFile(
+            "[client]\n"
+            "computer_title = Old Title\n"
+            "account_name = Old Name\n"
+            "registration_key = Old Password\n"
+            "http_proxy = http://old.proxy\n"
+            "https_proxy = https://old.proxy\n"
+            "url = http://url\n",
+        )
+
+        def side_effect_input(prompt):
+            fixtures = {
+                "[Old Title]": "New Title",
+                "[Old Name]": "New Name",
+                "[http://old.proxy]": "http://new.proxy",
+                "[https://old.proxy]": "https://new.proxy",
+                "Will you be using your own "
+                "Self-Hosted Landscape installation? [y/N]": "n",
+            }
+            for key, value in fixtures.items():
+                if key in prompt:
+                    return value
+
+        def side_effect_getpass(prompt):
+            fixtures = {
+                "(Optional) Registration Key:": "New Password",
+                "Please confirm:": "New Password",
+            }
+            for key, value in fixtures.items():
+                if key in prompt:
+                    return value
+
+        mock_input.side_effect = side_effect_input
+        mock_getpass.side_effect = side_effect_getpass
+
+        config = self.get_config(["--no-start", "--config", filename])
+        setup(config)
+
+        self.assertEqual(
+            "sudo landscape-client.config "
+            "--account-name 'New Name' "
+            "--registration-key HIDDEN "
+            "--https-proxy https://new.proxy "
+            "--http-proxy http://new.proxy",
+            mock_help.mock_calls[-1].args[0],
+        )
+
     @mock.patch("landscape.client.configuration.ServiceConfig")
     def test_silent_setup(self, mock_serviceconfig):
         """
@@ -1172,6 +1282,27 @@ registration_key = shared-secret
             "\nRequest a new registration for this computer now? [Y/n]: ",
         )
 
+    @mock.patch("landscape.client.configuration.input")
+    @mock.patch("landscape.client.configuration.register")
+    @mock.patch("landscape.client.configuration.setup")
+    def test_skip_registration(self, mock_setup, mock_register, mock_input):
+        """
+        Registration and input asking user to register is not called
+        when flag on
+        """
+        main(["-c", self.make_working_config(), "--skip-registration"],
+             print=noop_print)
+        mock_register.assert_not_called()
+        mock_input.assert_not_called()
+
+    @mock.patch("landscape.client.configuration.register")
+    @mock.patch("landscape.client.configuration.setup")
+    def test_main_no_registration_silent(self, mock_setup, mock_register):
+        """Skip registration works in silent mode"""
+        main(["-c", self.make_working_config(), "--skip-registration",
+              "--silent"], print=noop_print)
+        mock_register.assert_not_called()
+
     @mock.patch(
         "landscape.client.configuration.register",
         return_value="success",
@@ -2080,7 +2211,8 @@ registration_key = shared-secret
         mock_print_text.assert_called_once_with(
             f"Writing SSL CA certificate to {key_filename}...",
         )
-        self.assertEqual("Hi there!", open(key_filename).read())
+        with open(key_filename) as fh:
+            self.assertEqual("Hi there!", fh.read())
 
         options = ConfigParser()
         options.read(config_filename)
